## PatientMatcher
PatientMatcher is a **Python** (Flask) and **MongoDB** - based implementation of a [MatchMaker Exchange](https://www.matchmakerexchange.org/) (MME) server, developed and actively maintained by [Clinical Genomics, Science For Life Laboratory in Stockholm](https://www.scilifelab.se/units/clinical-genomics-stockholm/). PatientMatcher is designed as a standalone application, but can easily communicate with external applications via REST API. The MME Stockholm node is being implemented in clinical production in collaboration with the Genomic Medicine Center Karolinska at the Karolinska University Hospital.  

This documentation pages are intended for providing users a **quick introduction** on how to test the application and set up PatientMatcher both on a staging and a production environment. A more detailed documentation and further description of background concepts are provided in [our paper][paper].  

The easiest way to test PatientMatcher is to run it on a local computer using Docker (instructions available [here](docker_app.md)).










[paper]: https://onlinelibrary.wiley.com/doi/10.1002/humu.24358
